#!/usr/bin/python
#
# Copyright 2010, Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author: Chris Lumens <clumens@redhat.com>

import sys

from cases import *

class FSOnPartitionRunner(BaseRunner):
    def writeKickstart(self):
        fo = open("/tmp/kickstart.ks", "w")
        fo.write("clearpart --all\n")
        fo.write("zerombr\n")
        fo.write("part /boot --asprimary --fstype=%s --size=500\n" % self.fstype)
        fo.write("part swap --fstype=swap --recommended\n")
        fo.write("part / --fstype=%s --grow --size=2048\n" % self.fstype)
        fo.close()

class FSOnPartitionTestCase(BaseTestCase):
    def test_boot(self):
        self.default_test_boot(self.fstype)

    def test_root(self):
        rootDev = self.single(self.getDevs(self.state, mountpoint="/"))
        self.failIf(not rootDev,
                    "Partitioning did not create /.")

        # Check the fs type and underlying device of /.
        self.assert_(rootDev["format"]["type"] == self.fstype,
                     "Type of / is not %s." % self.fstype)
        self.assertTrue(self.onPartition(rootDev),
                     "/ was not created on a partition.")

    def test_swap(self):
        from pyanaconda.iutil import swapSuggestion

        swapDev = self.single(self.getDevs(self.state, format="swap"))
        self.failIf(not swapDev,
                    "Partitioning did not create swap.")

        # Swap size can vary wildly, so just check that swap exists and is inside
        # the range anaconda suggests.
        (minSwap, maxSwap) = swapSuggestion()
        self.assert_(minSwap <= swapDev["size"] <= maxSwap,
                     "swap is not within suggested range")

        # Check the fs type and underlying device of swap.
        self.assert_(swapDev["format"]["type"] == "swap",
                     "Type of swap is not swap.")
        self.assertTrue(self.onPartition(swapDev),
                        "swap was not created on a partition.")
