#!/usr/bin/python
#
# Copyright 2010, Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author: Chris Lumens <clumens@redhat.com>

import os

from cases import RAID0

class RAID1Runner(RAID0.RAID0Runner):
    def writeKickstart(self):
        fo = open("/tmp/kickstart.ks", "w")
        fo.write("clearpart --all\n")
        fo.write("zerombr\n")
        fo.write("part /boot --fstype=ext4 --size=500\n")
        fo.write("part swap --fstype=swap --recommended\n")
        fo.write("part raid.01 --size=2048\n")
        fo.write("part raid.02 --size=2048\n")
        fo.write("raid / --device=0 --fstype=ext4 --level=RAID1 raid.01 raid.02\n")
        fo.close()

class RAID1TestCase(RAID0.RAID0TestCase):
    """Verify we have the following:

       - 500 MB /boot partition
       - swap partition with size inside our recommendations
       - two equally sized partitions with a RAID format
       - / on md0
    """
    def test_raid(self):
        # Check that we created two equal sized partitions of type mdmember.
        members = self.getDevs(self.state, format="mdmember")
        self.assert_(len(members) == 2,
                     "Partitioning did not create exactly two RAID members.")
        self.assert_(members[0]["length"] == members[1]["length"],
                     "Partitioning did not create equal sized RAID members.")

        # Check that we created a RAID1 device.
        raid = self.single(self.getDevs(self.state, type="mdarray"))
        self.assert_(raid["level"] == 1,
                     "Device is not RAID1.")
