#!/usr/bin/python
#
# Copyright 2010, Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author: Chris Lumens <clumens@redhat.com>

import sys

from pyanaconda import anaconda_log
anaconda_log.init()

from pyanaconda.cmdline import InstallInterface
from pyanaconda.storage.errors import StorageError

# doAutoPartition in anaconda doesn't always raise exceptions on errors.
# Sometimes (like when there's an error the user could recover from), it shows
# a dialog instead.  In kickstart mode, it just displays an error message and
# exits.  That's not useful for storage testing as we can't detect that
# situation.  So, create a new InstallInterface class that's the same as
# the cmdline mode except for raising exceptions always.
class TestInstallInterface(InstallInterface):
    def messageWindow(self, title, text, type="ok", default=None,
                      custom_icon=None, custom_buttons=[]):
        if type == "ok":
            InstallInterface.messageWindow(self, title, text, type, default,
                                           custom_icon, custom_buttons)
        else:
            raise StorageError(title + "\n\n" + text)

    def kickstartErrorWindow(self, text):
        raise StorageError("The following error was found while parsing the "
                           "kickstart configuration file:\n\n%s" % text)
