#!/usr/bin/python
#
# This is the script that controls the whole automatic storage testing
# framework.  It creates and caches live CD images, finds test suites, and
# spawns VMs to run those test suites.  It also runs a server to accept
# test results from the VMs.
#
# Copyright 2010, Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author: Chris Lumens <clumens@redhat.com>

import logging
import os, sys
from optparse import OptionParser

if __name__ == "__main__":
    if os.geteuid() != 0:
        logging.critical("You must be root to run this program.")
        sys.exit(1)

    op = OptionParser(usage="%program [options] [test]")
    op.add_option("--basedir")
    op.add_option("--diskimagesdir")
    op.add_option("--kickstart")
    op.add_option("--livecddir")
    op.add_option("--resultsdir")
    op.add_option("--suitedir")
    op.add_option("--tmpdir")
    op.add_option("-r", "--repo", dest="repos", default=[], action="append")

    (opts, extra) = op.parse_args(sys.argv[1:])

    # Must provide at least one repository url
    if len(opts.repos) <= 0:
        op.error("No repository URLs provided (-r|--repo)")

    args = []
    kwargs = {"repos": opts.repos}

    if opts.basedir:
        kwargs["basedir"] = opts.basedir
    if opts.diskimagesdir:
        kwargs["diskimagesdir"] = opts.diskimagesdir
    if opts.kickstart:
        kwargs["kickstart"] = opts.kickstart
    if opts.livecddir:
        kwargs["livecddir"] = opts.livecddir
    if opts.resultsdir:
        kwargs["resultsdir"] = opts.resultsdir
    if opts.suitedir:
        kwargs["suitedir"] = opts.suitedir
    if opts.tmpdir:
        kwargs["tmpdir"] = opts.tmpdir

    logging.basicConfig(level=logging.INFO)

    framework = StorageTestFramework(*args, **kwargs)
    framework.setupDirs()
    framework.startReportServer()
    framework.run(extra)
